@@ -17,20 +17,11 @@ def womg_main(graph=None,
               infl_strength=12.,
               virality_exp=8.,
               virality_resistance=13.,
-              interests_path=None,
+              interests=None,
               int_mode='nmf',
               weighted=False, directed=False,
               path_out=None,
               seed=None,
-              walk_length=100,
-              num_walks=10,  window_size=10,
-              iiter=1, workers=1,
-              p=1, q=1,
-              beta=0.01,
-              norm_prior=False,
-              alpha_value=2.,
-              beta_value=2.,
-              prop_steps=1000,
               progress_bar=True,
               save_all=False,
               save_int=False,
@@ -104,44 +95,6 @@ def womg_main(graph=None,
         seed (int) for random distribution extractions
 
 
-    walk_length : int
-        [node2vec param] length of walk per source. Default 80
-
-    num_walks : int
-        [node2vec param] number of walks per source. Default 10
-
-    window_size : int
-        [node2vec param] context size for optimization. Default 10
-
-    iiter : int
-        [node2vec param] number of epochs in SGD
-
-    workers: int
-        [node2vec param] number of parallel workers. Default 8
-
-    p : float
-        [node2vec param] manually set BFS parameter; else: it is set by H
-
-    q : float
-        [node2vec param] manually set DFS parameter; else: it is set by H
-
-
-    beta : float
-        beta cost parameter for Beta-VAE loss term. Default  0.01
-
-    norm_prior : bool
-        choose half normal distribution as prior function for Beta-VAE loss term. Default False -> beta distribution
-
-    alpha_value : float
-        alpha value for the alpha vec of the Beta prior distribution. Default 2.
-    beta_value : float
-        beta value for the beta vec of the Beta prior distribution. Default 2.
-
-
-    prop_steps : int
-        [propagation of interests param] sets the number of steps in the propagation
-        high value imposes high homophily in the interests
-
     progress_bar : bool
         boolean for specifying the progress bar related to the environment
         if True progress_bar=tqdm_notebook -> Jupyter progress_bar;
@@ -168,35 +121,26 @@ def womg_main(graph=None,
                       progress_bar=progress_bar)
     topic_model.fit()
     prop = womgc(graph=graph,
-                numb_topics=numb_topics,
-                numb_docs=numb_docs,
-                homophily=homophily,
-                weighted=weighted,
-                directed=directed,
-                interests_path=interests_path,
-                gn_strength=gn_strength,
-                infl_strength=infl_strength,
-                p=p, q=q,
-                num_walks=num_walks, walk_length=walk_length,
-                window_size=window_size,
-                workers=workers, iiter=iiter,
-                progress_bar=progress_bar,
-                beta=beta,
-                norm_prior=norm_prior,
-                alpha_value=alpha_value,
-                beta_value=beta_value,
-                prop_steps=prop_steps,
-                seed=seed,
-                items_descr=topic_model.items_descript,
-                virality_exp=virality_exp,
-                single_activator=single_activator,
-                virality_resistance=virality_resistance,
-                numb_steps=numb_steps,
-                path_out=path_out,
-                save_all=save_all,
-                save_int=save_int,
-                save_infl=save_infl,
-                save_keyw=save_keyw)
+                 numb_topics=numb_topics,
+                 numb_docs=numb_docs,
+                 homophily=homophily,
+                 weighted=weighted,
+                 directed=directed,
+                 interests=interests,
+                 gn_strength=gn_strength,
+                 infl_strength=infl_strength,
+                 seed=seed,
+                 items_descr=topic_model.items_descript,
+                 virality_exp=virality_exp,
+                 single_activator=single_activator,
+                 virality_resistance=virality_resistance,
+                 numb_steps=numb_steps,
+                 progress_bar=progress_bar,
+                 path_out=path_out,
+                 save_all=save_all,
+                 save_int=save_int,
+                 save_infl=save_infl,
+                 save_keyw=save_keyw)
 
     return prop
 
@@ -227,11 +171,11 @@ def womg_main(graph=None,
 
 @click.option('--graph', default=None,
                     help='Input path of the graph edgelist or nx object', type=str)
-@click.option('--interests_path', default=None,
+@click.option('--interests', default=None,
                     help='Input path of the ginterests table', type=str)
 
 @click.option('--int_mode', type=str,
-                    help="defines the method for generating nodes' interests. 3 choices: 'n2i', 'rand', 'prop_int'. Default 'nmf' ",
+                    help="defines the method for generating nodes' interests. 2 choices: 'rand', 'nmf'. Default 'nmf' ",
                     default='nmf')
 
 @click.option('--weighted', is_flag=True,
@@ -251,41 +195,9 @@ def womg_main(graph=None,
                     type=int, required=False)
 
 
-
-@click.option('--walk_length', metavar='w', type=int, default=80,
-                    help='length of walk per source. Default 80')
-
-@click.option('--num_walks', metavar='nw', type=int, default=10,
-                    help='number of walks per source. Default 10')
-
-@click.option('--window_size', metavar='ws', type=int, default=10,
-                    help='context size for optimization. Default 10')
-
-@click.option('--iiter', default=1, type=int,
-                  help='number of epochs in SGD')
-
-@click.option('--workers', type=int, default=8,
-                    help='number of parallel workers. Default 8')
-
-@click.option('--p', type=float, default=1,
-                    help='manually set BFS parameter; else: it is set by H')
-
-@click.option('--q', type=float, default=1,
-                    help='manually set DFS parameter; else: it is set by H')
 @click.option('--progress_bar', is_flag=True,
                     help='boolean for specifying the progress bar related to the environment if True progress_bar=tqdm_notebook -> Jupyter progress_bar; if False progress_bar=tqdm. Default False ',
                     default=True)
-@click.option('--beta', type=float, default=0.01,
-                    help='beta cost parameter for Beta-VAE loss term. Default  0.01')
-@click.option('--norm_prior', is_flag=True, default=False,
-                    help='choose half normal distribution as prior function for Beta-VAE loss term. Default  beta distribution')
-@click.option('--alpha_value', type=float, default=2.,
-                    help='alpha value for the alpha vec of the Beta prior distribution. Default 2.')
-@click.option('--beta_value', type=float, default=2.,
-                    help='beta value for the beta vec of the Beta prior distribution. Default 2.')
-
-@click.option('--prop_steps', type=int, default=5000,
-                    help='propagation steps for interests generation in propagation mode (--int_mode prop_int). Default 5000')
 
 @click.option('--save_int', is_flag=True,
                     help='if True WoMG saves the interests vector for each node',
@@ -308,21 +220,12 @@ def main_cli(graph,
              topics, docs, steps, homophily,
              virality_exp,
              virality_resistance,
-             interests_path,
+             interests,
              int_mode,
              weighted, directed, docs_folder,
              gn_strength,
              infl_strength,
              output, seed,
-             walk_length,
-             num_walks, window_size,
-             iiter, workers,
-             p, q,
-             beta,
-             norm_prior,
-             alpha_value,
-             beta_value,
-             prop_steps,
              progress_bar,
              single_activator,
              save_all,
@@ -348,20 +251,11 @@ def main_cli(graph,
               infl_strength=infl_strength,
               virality_exp=virality_exp,
               virality_resistance=virality_resistance,
-              interests_path=interests_path,
+              interests=interests,
               int_mode=int_mode,
               weighted=weighted, directed=directed,
               path_out=output,
               seed=seed,
-              walk_length=walk_length,
-              num_walks=num_walks, window_size=window_size,
-              iiter=iiter, workers=workers,
-              p=p, q=q,
-              beta=beta,
-              norm_prior=norm_prior,
-              alpha_value=alpha_value,
-              beta_value=beta_value,
-              prop_steps=prop_steps,
               progress_bar=progress_bar,
               save_all=save_all,
               save_int=save_int,
