@@ -7,6 +7,7 @@ import gensim
 import pickle
 from tqdm import tqdm, tqdm_notebook
 import numpy as np
+import womg_core
 from womg_core.topic.tlt_topic_model import TLTTopicModel
 from womg_core.utils.utility_functions import count_files, read_docs, TopicsError, DocsError
 from womg_core.utils.distributions import random_powerlaw_vec
@@ -42,7 +43,7 @@ class LDA(TLTTopicModel):
         self.items_keyw = {}
         self.dictionary = []
         #self.main_data_path = pathlib.Path(os.path.abspath(womg.__file__).replace('/womg/__init__.py', ''))/'womgdata'
-        self.main_data_path = pathlib.Path(os.path.abspath(womg.__file__).replace('/womg/__init__.py', ''))/'womgdata'
+        self.main_data_path = pathlib.Path(os.path.abspath(womg_core.__file__).replace('/womg_core/__init__.py', ''))/'womgdata'
         self._training_path = self.main_data_path /'docs'/'training_corpus_ap'
         #print(self._training_path)
         if progress_bar:
